import numpy as np
from h5py import Group
from dataclasses import dataclass
from typing import ClassVar, Literal



@dataclass
class CommonVectors:
    UV: ClassVar[list[str]] = ['u', 'v']
    XYZ: ClassVar[list[str]] = ['x', 'y', 'z']
    QUAT: ClassVar[list[str]] = ['x', 'y', 'z', 'w']


UVElement = Literal['u', 'v']
XYZElement = Literal['x', 'y', 'z']
QUATElement = Literal['x', 'y', 'z', 'w']
VectorElement = Literal[UVElement, XYZElement, QUATElement]


def extract_vector(h5_group: Group, indices: slice, dataset_list: list[VectorElement]):
    extracted_data = np.stack(
        [h5_group[element][indices] for element in dataset_list],
        axis=-1
    )
    return extracted_data



if __name__ == '__main__':
    from h5py import File


    test_file = File("./examples/projection_geometry.h5", "r")

    detector_center_position_mm = extract_vector(test_file['detector_center_position_mm'], slice(2), CommonVectors.XYZ)
    print(detector_center_position_mm)